@@ -82,6 +82,6 @@ class Comment(Entity):
 
         return commentRepository.getComments(self, count)
 
-    def export(self, rootPath):
+    def export(self, rootPath, nameInFolderName=True):
         from labstep.entities.comment.repository import commentRepository
-        return commentRepository.exportComment(self, rootPath)
+        return commentRepository.exportComment(self, rootPath, nameInFolderName=nameInFolderName)
