@@ -7,6 +7,7 @@ from labstep.generic.entity.repository import entityRepository
 from labstep.entities.file.repository import fileRepository
 from labstep.service.helpers import handleString
 
+
 class CommentRepository:
     def getComments(self, entity, count=100, extraParams={}):
 
@@ -46,15 +47,17 @@ class CommentRepository:
         params = {"body": body, **extraParams}
         return entityRepository.editEntity(comment, params)
 
-    def exportComment(self, comment, rootPath):
-        commentDir = entityRepository.exportEntity(comment, rootPath)
+    def exportComment(self, comment, rootPath, nameInFolderName=True):
+        commentDir = entityRepository.exportEntity(
+            comment, rootPath, nameInFolderName=nameInFolderName)
 
         # export comment
         nestedCommentsDir = commentDir.joinpath('comments')
         nestedComments = comment.getComments(count=1000)
 
         for nestedComment in nestedComments:
-            nestedComment.export(nestedCommentsDir)
+            nestedComment.export(
+                nestedCommentsDir, nameInFolderName=nameInFolderName)
 
 
 commentRepository = CommentRepository()
