@@ -268,6 +268,36 @@ class Experiment(PrimaryEntity):
         }
         return entityRepository.newEntity(self.__user__, ExperimentSignature, params)
 
+    def getSignatureRequests(self):
+        """
+        Returns a list of pending signature requests for the experiment.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.experimentSignatureRequest.model.ExperimentSignatureRequest`]
+        """
+        from labstep.entities.experimentSignatureRequest.repository import experimentSignatureRequestRepository
+
+        return experimentSignatureRequestRepository.getExperimentSignatureRequests(self.__user__, self.id)
+
+    def requestSignature(self, user_id, message=None):
+        """
+        Request a signature from another user in the workspace
+
+        Parameters
+        ----------
+
+        user_id (int)
+            Id of the user you are requesting a signature from
+
+        message (str)
+            Optional message to include in signature request email
+
+        """
+        from labstep.entities.experimentSignatureRequest.repository import experimentSignatureRequestRepository
+
+        return experimentSignatureRequestRepository.newExperimentSignatureRequest(self.__user__, self.id, user_id=user_id, message=message)
+
     def getMaterials(self):
         """
         Returns a list of the materials in the Experiment.
