@@ -78,11 +78,12 @@ class ExperimentRepository:
 
         return entityRepository.editEntity(experiment, params)
 
-    def exportExperiment(self, experiment, root_path):
+    def exportExperiment(self, experiment, root_path, nameInFolderName=True):
 
         experiment.update()
 
-        expDir = entityRepository.exportEntity(experiment, root_path)
+        expDir = entityRepository.exportEntity(
+            experiment, root_path, nameInFolderName=nameInFolderName)
 
         # export entry
         experiment.root_experiment.export(expDir, folderName='entry')
@@ -92,14 +93,14 @@ class ExperimentRepository:
         protocols = experiment.getProtocols(count=100)
 
         for protocol in protocols:
-            protocol.export(protocolsDir)
+            protocol.export(protocolsDir, nameInFolderName=nameInFolderName)
 
         # export notes
         notesDir = expDir.joinpath('notes')
         notes = experiment.getComments(count=1000)
 
         for note in notes:
-            note.export(notesDir)
+            note.export(notesDir, nameInFolderName=nameInFolderName)
 
         # get html
         html = htmlExportService.getHTML(experiment)
