@@ -415,6 +415,6 @@ class ExperimentProtocol(Entity):
         files = self.files
         return listToClass(files, File, self.__user__)
 
-    def export(self, rootPath, folderName=None):
+    def export(self, rootPath, folderName=None, nameInFolderName=True):
         from labstep.entities.experimentProtocol.repository import experimentProtocolRepository
-        return experimentProtocolRepository.exportExperimentProtocol(self, rootPath, folderName)
+        return experimentProtocolRepository.exportExperimentProtocol(self, rootPath, folderName=folderName, nameInFolderName=nameInFolderName)
