@@ -6,26 +6,26 @@ from labstep.generic.entity.repository import entityRepository
 
 
 class ExperimentProtocolRepository:
-    def exportExperimentProtocol(self, experimentProtocol, rootPath, folderName):
+    def exportExperimentProtocol(self, experimentProtocol, rootPath, folderName, nameInFolderName=True):
 
         experimentProtocol.update()
 
         expDir = entityRepository.exportEntity(
-            experimentProtocol, rootPath, folderName)
+            experimentProtocol, rootPath, folderName=folderName, nameInFolderName=nameInFolderName)
 
         # save materials
         materialsDir = expDir.joinpath('materials')
         materials = experimentProtocol.getMaterials()
 
         for material in materials:
-            material.export(materialsDir)
+            material.export(materialsDir, nameInFolderName=nameInFolderName)
 
         # save data
         dataDir = expDir.joinpath('data')
         data = experimentProtocol.getDataElements()
 
         for dat in data:
-            dat.export(dataDir)
+            dat.export(dataDir, nameInFolderName=nameInFolderName)
 
 
 experimentProtocolRepository = ExperimentProtocolRepository()
