@@ -6,7 +6,7 @@ from labstep.generic.entity.model import Entity
 
 
 class OrganizationUser(Entity):
-    __entityName__ = "user_organization"
+    __entityName__ = "user-organization"
 
     def promote(self):
         """
