@@ -22,9 +22,11 @@ class User(Entity):
         print(user.name)
         print(user.id)
     """
+    __entityName__ = "user"
 
-    def __init__(self, user):
-        if user["group"] is None:
+    def __init__(self, user, adminUser=None):
+        self.__user__ = adminUser if adminUser is not None else self
+        if 'group' not in user or user["group"] is None:
             print(
                 """Warning: No default workspace.
             Please set a workspace to continue."""
