@@ -36,7 +36,7 @@ class Entity:
         self.__init__(data, self.__user__)
         return self
 
-    def export(self, rootPath, folderName=None):
+    def export(self, rootPath, folderName=None, nameInFolderName=True):
         """
         Export the entity to the directory specified. 
 
@@ -53,4 +53,4 @@ class Entity:
             experiment.export('/my_folder')
         """
         from labstep.generic.entity.repository import entityRepository
-        return entityRepository.exportEntity(self, rootPath, folderName=folderName)
+        return entityRepository.exportEntity(self, rootPath, folderName=folderName, nameInFolderName=nameInFolderName)
