@@ -4,6 +4,7 @@
 
 import json
 from pathlib import Path
+from pathvalidate import sanitize_filepath
 from labstep.service.config import API_ROOT
 from labstep.service.helpers import (
     listToClass,
@@ -33,7 +34,7 @@ class EntityRepository:
             return entityClass(json.loads(response.content), user)
 
     def getEntities(self, user, entityClass, count, filterParams={}):
-        countParameter = min(count, 50)
+        countParameter = min(count, 50) if count is not None else None
         searchParams = {"search": 1, "cursor": -1, "count": countParameter}
 
         params = {**searchParams, **filterParams}
@@ -43,7 +44,8 @@ class EntityRepository:
         response = requestService.get(url, params=params, headers=headers)
         resp = json.loads(response.content)
         items = resp["items"]
-        expectedResults = min(resp["total"], count)
+        expectedResults = min(
+            resp["total"], count) if count is not None else resp["total"]
         while len(items) < expectedResults:
             params["cursor"] = resp["next_cursor"]
             response = requestService.get(url, headers=headers, params=params)
@@ -87,15 +89,18 @@ class EntityRepository:
         entity.__init__(json.loads(response.content), entity.__user__)
         return entity
 
-    def exportEntity(self, entity, rootPath, folderName=None):
+    def exportEntity(self, entity, rootPath, folderName=None, nameInFolderName=True):
 
         from labstep.entities.file.model import File
 
         if folderName is None:
-            folderName = f'{entity.id} - {entity.name}' if hasattr(
-                entity, 'name') else f'{entity.id}'
+            if nameInFolderName:
+                folderName = f'{entity.id} - {entity.name}' if hasattr(
+                    entity, 'name') else f'{entity.id}'
+            else:
+                folderName = str(entity.id)
 
-        entityDir = Path(rootPath).joinpath(folderName)
+        entityDir = Path(rootPath).joinpath(sanitize_filepath(folderName))
         entityDir.mkdir(parents=True, exist_ok=True)
         infoFile = entityDir.joinpath('entity.json')
 
